@@ -10,7 +10,8 @@ NULL
   # BuildDate <- pkgdes$Date
 
   foo <- paste(#"## \n##  magi (Version ", version, ", Build Date: ", BuildDate, ")\n",
-               "##  See https://github.com/wongswk/magi for additional documentation.\n",
+               "##  See vignette https://arxiv.org/abs/2203.06066 for detailed usage instructions, \n",
+               "##  and https://github.com/wongswk/magi for additional documentation.\n",
                "##  \n",
                "##  Please cite MAGI method as:\n",
                "##  Yang, S., Wong, S.W. and Kou, S.C., 2021.\n",
