@@ -28,32 +28,6 @@ Rcpp::List phisigllikC(const arma::vec & phisig,
                       Named("grad")=ret.gradient);
 }
 
-//' R wrapper for phisigllik
-//' phi sigma leave-one-out-cross-validation log-likelihood for setting hyper-paramters. This idea is not used in the final method
-//' @noRd
-// [[Rcpp::export]]
-Rcpp::List phisigloocvllikC(const arma::vec & phisig, 
-                            const arma::mat & yobs, 
-                            const arma::mat & dist, 
-                            std::string kernel="matern"){
-  lp ret = phisigloocvllik(phisig, yobs, dist, kernel);
-  return List::create(Named("value")=ret.value,
-                      Named("grad")=ret.gradient);
-}
-
-//' R wrapper for phisigloocvmse
-//' phi sigma leave-one-out-cross-validation mean-squared-error for setting hyper-paramters. This idea is not used in the final method
-//' @noRd
-// [[Rcpp::export]]
-Rcpp::List phisigloocvmseC(const arma::vec & phisig, 
-                           const arma::mat & yobs, 
-                           const arma::mat & dist, 
-                           std::string kernel="matern"){
-  lp ret = phisigloocvmse(phisig, yobs, dist, kernel);
-  return List::create(Named("value")=ret.value,
-                      Named("grad")=ret.gradient);
-}
-
 
 //' sample from GP marginal likelihood for phi and sigma
 //' Internal function for debugging purpose
@@ -243,79 +217,6 @@ Rcpp::List xthetaSample( const arma::mat & yobs,
   return ret;
 }
 
-//' parallel tempered version of hmc for xtheta sample
-//'
-//' not used in the final method, in final method, only one temperature with heating is needed
-//'
-//' @noRd
-// [[Rcpp::export]]
-arma::cube parallel_temper_hmc_xtheta( const arma::mat & yobs,
-                                       const Rcpp::List & covVr, 
-                                       const Rcpp::List & covRr, 
-                                       const arma::vec & sigmaInput,
-                                       const arma::vec & temperature, 
-                                       const double & alpha0, 
-                                       const arma::vec & initial, 
-                                       const arma::vec & step, 
-                                       int nsteps = 1, 
-                                       int niter=1e4){
-  vec sigma( yobs.n_cols);
-  if(sigmaInput.size() == 1){
-    sigma.fill( as_scalar( sigmaInput));
-  }else if(sigmaInput.size() == yobs.n_cols){
-    sigma = sigmaInput;
-  }else{
-    throw std::runtime_error("sigmaInput size not right");
-  }
-  
-  vector<gpcov> covAllDimensions(2);
-  covAllDimensions[0] = cov_r2cpp(covVr);
-  covAllDimensions[1] = cov_r2cpp(covRr);
-  
-  OdeSystem fnmodel(fnmodelODE, fnmodelDx, fnmodelDtheta, zeros(3), ones(3)*datum::inf);
-  
-  
-  std::function<lp(vec)> tgt = std::bind(xthetallik, std::placeholders::_1, 
-                   covAllDimensions, sigma, yobs, fnmodel, true, arma::ones(1));
-  
-  vec lb = ones<vec>(initial.size()) * (-datum::inf);
-  lb.subvec(lb.size() - 3, lb.size() - 1).fill(0.0);
-  
-  std::function<mcmcstate(std::function<lp(vec)>, mcmcstate)> hmc_simple =
-    [step, lb, nsteps](std::function<lp(vec)> tgt_tempered, mcmcstate currstate) -> mcmcstate{
-      currstate.lpv = tgt_tempered(currstate.state).value;
-      vec rstep = arma::randu<vec>(step.size()) % step  + step;
-      hmcstate post = basic_hmcC(tgt_tempered, currstate.state, rstep, lb,
-                                 {arma::datum::inf}, nsteps, true);
-      // cout << post.trajH;
-      return mcmcstate(post);
-    };
-    
-  
-  // cout << "test tgt value = " << tgt(initial).value 
-  //      << " &tgt = " << &tgt << endl;
-  // cout << "test & HMC func = " << &basic_hmcC << endl;
-  
-  mcmcstate init_mcmcstate;
-  init_mcmcstate.state = initial;
-  mcmcstate initpost_mcmcstate = hmc_simple(tgt, init_mcmcstate);
-  // cout << "test hmc_simple = " << initpost_mcmcstate.lpv << endl
-  //      << initpost_mcmcstate.acc << endl;
-       // << initpost_mcmcstate.state << endl;
-  
-  // cout << "prepare to call parallel_termperingC" << endl;
-  
-  cube samples = parallel_termperingC(tgt,
-                                      hmc_simple,
-                                      temperature,
-                                      initial,
-                                      alpha0,
-                                      niter,
-                                      true);
-  return samples;
-  // return arma::zeros<cube>(1,1,1);
-}
-
 
 //' R wrapper for xthetallik
 //' Calculate the log posterior of x and theta, without sigma
